Muffin-Mongo
############

.. _description:

Muffin-Mongo -- Short description.

.. _badges:

.. image:: http://img.shields.io/travis/klen/muffin-mongo.svg?style=flat-square
    :target: http://travis-ci.org/klen/muffin-mongo
    :alt: Build Status

.. image:: http://img.shields.io/coveralls/klen/muffin-mongo.svg?style=flat-square
    :target: https://coveralls.io/r/klen/muffin-mongo
    :alt: Coverals

.. image:: http://img.shields.io/pypi/v/muffin-mongo.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-mongo

.. image:: http://img.shields.io/pypi/dm/muffin-mongo.svg?style=flat-square
    :target: https://pypi.python.org/pypi/muffin-mongo

.. image:: http://img.shields.io/gratipay/klen.svg?style=flat-square
    :target: https://www.gratipay.com/klen/
    :alt: Donate

.. _documentation:

**Docs are available at https://muffin-mongo.readthedocs.org/. Pull requests
with documentation enhancements and/or fixes are awesome and most welcome.**

.. _contents:

.. contents::

.. _requirements:

Requirements
=============

- python >= 2.6

.. _installation:

Installation
=============

**Muffin-Mongo** should be installed using pip: ::

    pip install muffin-mongo

.. _usage:

Usage
=====

.. _bugtracker:

Bug tracker
===========

If you have any suggestions, bug reports or
annoyances please report them to the issue tracker
at https://github.com/klen/muffin-mongo/issues

.. _contributing:

Contributing
============

Development of Muffin-Mongo happens at: https://github.com/klen/muffin-mongo


Contributors
=============

* klen_ (Kirill Klenov)

.. _license:

License
=======

Licensed under a `MIT license`_.

.. _links:


.. _klen: https://github.com/klen

.. _MIT license: http://opensource.org/licenses/MIT